@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009-2014
+* (C) Francesco Mondello 2009-2016
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -68,13 +68,26 @@ void DialogOptions::setOverwriteMode()
     if (radioAskFirst->isChecked())
         IniSettings::setOverwriteMode(true);
 	else
-		IniSettings::setOverwriteMode(false);
+        IniSettings::setOverwriteMode(false);
+}
+
+void DialogOptions::setAutoUpdates()
+{
+    bool enabled;
+
+    if (checkCheckUpdates->isChecked())
+        enabled = true;
+    else
+        enabled = false;
+
+    IniSettings::setAutoChechUpdates(enabled);
 }
 
 void DialogOptions::saveOptions()
 {
     setLanguage();
     setOverwriteMode();
+    setAutoUpdates();
 
     accept();
 }
@@ -84,6 +97,12 @@ void DialogOptions::loadSettings()
     bool overwriteMode = IniSettings::isOverwriteMode();
 	radioAskFirst->setChecked(overwriteMode);
 
+    bool autoUpdates = IniSettings::isAutoChechUpdates();
+    if (autoUpdates)
+        checkCheckUpdates->setCheckState(Qt::Checked);
+    else
+        checkCheckUpdates->setCheckState(Qt::Unchecked);
+
     Translator t;
     
     int idx = comboLangs->findText(t.currentLanguage(), Qt::MatchExactly);
