@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009-2014
+* (C) Francesco Mondello 2009-2016
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ QStringList Formats::s_writableFilters;
 
 void Formats::loadFormats()
 {
-#ifdef Q_OS_LINUX
+#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
     list<CoderInfo> coderList;
     coderInfoList(&coderList,
                   CoderInfo::TrueMatch,
@@ -70,12 +70,9 @@ void Formats::loadFormats()
         }
 
         if (entry->isWritable()) {
-            QString currFormat = QString::fromStdString(entry->name()).toLower();
-            if (!(blacklist.contains(currFormat))) {
-                s_writableFilters << QString("%1 - (%2)")
-                                     .arg(QString::fromStdString(entry->name()))
-                                     .arg(QString::fromStdString(entry->description()));
-            }
+            s_writableFilters << QString("%1 - (%2)")
+                                 .arg(QString::fromStdString(entry->name()))
+                                 .arg(QString::fromStdString(entry->description()));
         }
 
         ++entry;
