@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009-2014
+* (C) Francesco Mondello 2009-2016
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -32,13 +32,15 @@
 #include "inisettings.h"
 #include "sizeutil.h"
 #include "updatechecker.h"
+#include "dialogmultipageeditor.h"
+#include "globals.h"
 
 using namespace Magick;
 using namespace std;
 
 // TODO: Inserire funzione per sostituire tutte le immagini
 
-MainWindowImpl::MainWindowImpl(QWidget * parent, Qt::WFlags f)
+MainWindowImpl::MainWindowImpl(QWidget * parent, Qt::WindowFlags f)
     : QMainWindow(parent, f)
 {
     setupUi(this);
@@ -91,29 +93,22 @@ MainWindowImpl::MainWindowImpl(QWidget * parent, Qt::WFlags f)
     adjustSize();
     dockWidget->adjustSize();
 
-    treeWidget->header()->setResizeMode(0, QHeaderView::ResizeToContents);
+    treeWidget->header()->setSectionResizeMode(0, QHeaderView::ResizeToContents);
 
     loadOptions();
 
     resetDisplays();
 
-    QTimer::singleShot(10000, this, SLOT(checkForUpdates()));
+    if (IniSettings::isAutoChechUpdates()) {
+        checkForUpdates();
+    }
+
+    checkVersion();
 }
 
 MainWindowImpl::~MainWindowImpl()
 {
-    IniSettings::setWindowGeometry(saveGeometry());
-    IniSettings::setPreviewChecked(checkShowPreview->isChecked());
-    IniSettings::setScaleChecked(groupDimensions->isChecked());
-    IniSettings::setMeasure(comboResizeValues->currentIndex());
-    IniSettings::setAspectRatioChecked(checkRelative->isChecked());
-    IniSettings::setResolutionChecked(groupResolution->isChecked());
-    IniSettings::setImageDirChecked(checkSameDir->isChecked());
-    IniSettings::setRenameChecked(checkRename->isChecked());
-    IniSettings::setBgColorChecked(checkNoTransp->isChecked());
-    IniSettings::isOverWriteMode(checkOverwrite->isChecked());
-
-    IniSettings::settings->sync();
+    saveSettings();
 }
 
 void MainWindowImpl::importListFromArgv(QString fileName)
@@ -141,6 +136,8 @@ void MainWindowImpl::createActions()
     // "File" actions
     connect(actionOpenFiles, SIGNAL(triggered()), this, SLOT(openFiles()));
     connect(actionAddFiles, SIGNAL(triggered()), this, SLOT(addFiles()));
+    connect(actionImportWindowsIconIco, SIGNAL(triggered()), this, SLOT(importIcoFile()));
+    connect(actionImportPDFFile, SIGNAL(triggered()), this, SLOT(importPdfFile()));
 
     connect(actionShowOptions, SIGNAL(triggered()), this, SLOT(editSettings()));
     connect(actionClose, SIGNAL(triggered()), this, SLOT(close()));
@@ -159,8 +156,10 @@ void MainWindowImpl::createActions()
     connect(actionConvert, SIGNAL(triggered()), this, SLOT(elabora()));
 
     connect(actionInfo, SIGNAL(triggered()), this, SLOT(about()));
-    connect(actionDonate, SIGNAL(triggered()), this, SLOT(openPaypalLink()));
+    connect(actionDonatePaypal, SIGNAL(triggered()), this, SLOT(openPaypalLink()));
+    connect(actionDonateFlattr, SIGNAL(triggered()), this, SLOT(openFlattrLink()));
     connect(actionReportBug, SIGNAL(triggered()), this, SLOT(bugReport()));
+    connect(actionCheckForUpdates, SIGNAL(triggered()), this, SLOT(checkForUpdates()));
 }
 
 void MainWindowImpl::setupMenu()
@@ -168,6 +167,9 @@ void MainWindowImpl::setupMenu()
     menu_File->addAction(actionOpenFiles);
     menu_File->addAction(actionAddFiles);
     menu_File->addSeparator();
+    menu_File->addAction(actionImportWindowsIconIco);
+    menu_File->addAction(actionImportPDFFile);
+    menu_File->addSeparator();
     menu_File->addAction(actionShowOptions);
     menu_File->addSeparator();
     menu_File->addAction(actionClose);
@@ -203,12 +205,13 @@ void MainWindowImpl::createContextMenu()
 void MainWindowImpl::openFiles()
 {
     iAList->clear();
-    CachingSystem::clear();
     addFiles();
 }
 
 void MainWindowImpl::addFiles()
 {
+    CachingSystem::clear();
+
     QString path = IniSettings::latestOpenedDir();
 
     QString readableFiltersString = Formats::readableFiltersString();
@@ -220,6 +223,46 @@ void MainWindowImpl::addFiles()
         loadFiles(fileNames);
 }
 
+void MainWindowImpl::importIcoFile()
+{
+    QString path = IniSettings::latestOpenedDir();
+
+    QString fileName = QFileDialog::getOpenFileName(this,
+        tr("Open Icon file"), path, tr("Microsoft icon (*.ico *.icon)"));
+
+    if (!fileName.isEmpty())
+        openMultipageFile(fileName);
+}
+
+void MainWindowImpl::importPdfFile()
+{
+    QString path = IniSettings::latestOpenedDir();
+
+    QString fileName = QFileDialog::getOpenFileName(this,
+        tr("Open Pdf file"), path, tr("Portable Document Format (*.pdf)"));
+
+    if (!fileName.isEmpty())
+        openMultipageFile(fileName);
+}
+
+void MainWindowImpl::openMultipageFile(QString fileName)
+{
+    DialogMultipageEditor *dlg = new DialogMultipageEditor();
+
+    statusBar()->showMessage(tr("Analyzing the file. It may take a while, please wait..."));
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+    dlg->readFile(fileName);
+    QApplication::restoreOverrideCursor();
+    statusBar()->clearMessage();
+
+    dlg->exec();
+
+    if (dlg->result() == 1) {
+        QStringList fileNames = dlg->fileNames();
+        loadFiles(fileNames);
+    }
+}
+
 void MainWindowImpl::loadFiles(QStringList fileNames)
 {
     treeWidget->clear();
@@ -539,7 +582,7 @@ void MainWindowImpl::loadOptions()
 
     lineDirectory->setText(QDir::toNativeSeparators(IniSettings::outputDir()));
     comboWFormats->setCurrentIndex(IniSettings::latestWrittenFormatIndex());
-    checkOverwrite->setChecked(IniSettings::isOverWriteMode());
+    checkOverwrite->setChecked(IniSettings::isOverwriteMode());
 
     loadQuality();
 
@@ -709,7 +752,10 @@ void MainWindowImpl::editSettings()
     DialogOptions dlg;
     dlg.exec();
 
-    loadOptions();
+    if (dlg.result() == 1) {
+        saveSettings();
+        loadOptions();
+    }
 }
 
 void MainWindowImpl::about()
@@ -845,6 +891,46 @@ void MainWindowImpl::resetDisplays()
     labelPixelGeometry->setText("");
 }
 
+void MainWindowImpl::checkVersion()
+{
+    int savedVersion = IniSettings::currentVersion();
+    int currentVersion = globals::CURRENT_INTERNAL_VERSION;
+
+    if (savedVersion < currentVersion) {
+	        QString appVersion;
+
+    #ifdef Q_OS_WIN32
+        appVersion = QString("%1%2")
+                .arg(QCoreApplication::applicationVersion())
+                .arg(globals::Globals::signature());
+    #else
+        appVersion = QCoreApplication::applicationVersion();
+    #endif
+
+	QString welcomePage = QString("http://fasterland.net/redirects/welcome.php?product=converseen&version=%1")
+            .arg(appVersion);
+
+    QDesktopServices::openUrl(QUrl(welcomePage, QUrl::TolerantMode));
+    IniSettings::setCurrentVersion(currentVersion);
+    }
+}
+
+void MainWindowImpl::saveSettings()
+{
+    IniSettings::setWindowGeometry(saveGeometry());
+    IniSettings::setPreviewChecked(checkShowPreview->isChecked());
+    IniSettings::setScaleChecked(groupDimensions->isChecked());
+    IniSettings::setMeasure(comboResizeValues->currentIndex());
+    IniSettings::setAspectRatioChecked(checkRelative->isChecked());
+    IniSettings::setResolutionChecked(groupResolution->isChecked());
+    IniSettings::setImageDirChecked(checkSameDir->isChecked());
+    IniSettings::setRenameChecked(checkRename->isChecked());
+    IniSettings::setBgColorChecked(checkNoTransp->isChecked());
+    IniSettings::setOverwriteMode(checkOverwrite->isChecked());
+
+    IniSettings::settings->sync();
+}
+
 void MainWindowImpl::overwriteDialog(QString baseName)
 {
     /*
@@ -930,7 +1016,12 @@ QString MainWindowImpl::destinationPath()
 
 void MainWindowImpl::openPaypalLink()
 {
-    QDesktopServices::openUrl(QUrl("http://converseen.sourceforge.net/#donations", QUrl::TolerantMode));
+    QDesktopServices::openUrl(QUrl("https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=HQA6TBT5354FC", QUrl::TolerantMode));
+}
+
+void MainWindowImpl::openFlattrLink()
+{
+    QDesktopServices::openUrl(QUrl("http://flattr.com/thing/3332139/Converseen", QUrl::TolerantMode));
 }
 
 void MainWindowImpl::checkForUpdates()
