@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009-2014
+* (C) Francesco Mondello 2009-2016
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ class MainWindowImpl : public QMainWindow, public Ui::MainWindow
 {
     Q_OBJECT
 public:
-    MainWindowImpl( QWidget * parent = 0, Qt::WFlags f = 0 );
+    MainWindowImpl( QWidget * parent = 0, Qt::WindowFlags f = 0 );
     ~MainWindowImpl();
     void importListFromArgv(QString fileName);
 
