@@ -1,8 +1,8 @@
 /*
-* This file is part of Kawaii Emoji Messenger, a multiplatform Facebook client
-* based on the idea of bringing emoji on desktop.
+* This file is part of Converseen, an open-source batch image converter
+* and resizer.
 *
-* (C) Francesco Mondello 2014
+* (C) Francesco Mondello 2009-2016
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -21,13 +21,14 @@
 *
 */
 
-#include "updatechecker.h"
-#include <QMessageBox>
 #include <QDesktopServices>
+
+#include "updatechecker.h"
+#include "dialogshowupdatemsg.h"
 #include "globals.h"
 
 #define VERSION_URL "http://fasterland.net/software-updates/converseen-version.txt"
-#define DESTINATION_URL "http://converseen.sf.net/"
+#define DESTINATION_URL "http://converseen.fasterland.net/update/"
 
 UpdateChecker::UpdateChecker(QObject *parent) :
     QObject(parent)
@@ -68,11 +69,14 @@ void UpdateChecker::onNetworkReply(QNetworkReply* reply)
 void UpdateChecker::checkIfIsNewVersion(int version)
 {
     if (version > globals::CURRENT_INTERNAL_VERSION) {
-        int ret = QMessageBox::warning(0, tr("New version is available!"),
-                                       tr("A new version of Converseen is available!\nWould you download it?"),
-                                       QMessageBox::Ok | QMessageBox::No);
+        QString caption = QString(tr("New version is available!"));
+        QString message = QString(tr("A new version of %1 is available!\nWould you download it?"))
+                .arg(globals::PROGRAM_NAME);
 
-        if (ret == QMessageBox::Ok)
+        DialogShowUpdateMsg dlg(0, caption, message);
+
+        if (dlg.exec()) {
             QDesktopServices::openUrl(QUrl(DESTINATION_URL, QUrl::TolerantMode));
+        }
     }
 }
